@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "wttrin" "0.2.4"
+(define-package "wttrin" "20251113.2014"
   "Emacs Frontend for Service wttr.in."
   '((emacs       "24.4")
     (xterm-color "1.0"))
   :url "https://github.com/cjennings/emacs-wttrin"
-  :commit "9b98fedc44b1ddcebaa48df2975493b37797c2fb"
-  :revdesc "9b98fedc44b1"
+  :commit "bf989bb594680eb2e3b69f55752353aa33cb47bb"
+  :revdesc "bf989bb59468"
   :keywords '("weather" "wttrin" "games")
   :maintainers '(("Craig Jennings" . "c@cjennings.net")))
